; 6502 Badge Software
; Hardware design by Lee Hart
; Software design by Daryl Rictor
;
; This software is free to use and modify in any non-commercial application.
; Comericial use is prohibited without expressed, written permission from the author.
;
;   ========================
;  | VCF Board LED mapping  |       
;   ========================
;

;     A1 J A2
;      ,____
;   FH|\ | /|KB
;   G1|_\|/_|G2
;     | /|\ |
;   EN|/_|,\|LC .P
;     D1 M D2

;--------------------------------
;
;  Column Scan Address bits as wired
;   0  1  2  3  4  5  6  7    
;   8  8  8  8  8  8  8  8    
;
;--------------------------------
;
; Column Scan code table
;
LED_COL	.byte	$80, $81, $82, $83, $84, $85, $86, $87
;
;--------------------------------
;
; Segment mapping to IO port
;
; data bits as wired
;     data            Low address
;  7 6 5 4  3 2 1 0   7 6 5  4 3 2 1 0
;  l s f g1 j n m h   k a g2 d c b e dp
;
;--------------------------------
;
; Data byte segment map

LH = $01
LM = $02
LN = $04
LJ = $08
LG1= $10
LF = $20
LS = $40
LL = $80
; Low address segment map
LP = $01 
LE = $02
LB = $04
LC = $08
LD = $10
LG2= $20
LA = $40
LK = $80

FONT_TABLE

;		address			data				character

	.byte	255,			255				;  (space) 
	.byte	255-LC-LB-LP,		255				;  ! 
	.byte	255-LB,			255-LJ				;  " 
	.byte	255-LG2-LD-LC-LB,	255-LG1-LM-LJ			;  # 
	.byte	255-LG2-LD-LC-LA,	255-LG1-LF-LM-LJ		;  $ 
	.byte	255-LG2-LC-LK,		255-LG1-LF-LL-LM-LH-LJ-LN	;  % 
	.byte	255-LE-LD-LA,		255-LG1-LL-LH-LJ		;  & 
	.byte	255,			255-LJ				;  ' 
	.byte	255-LK,			255-LL				;  ( 
	.byte	255,			255-LH-LN			;  ) 
	.byte	255-LG2-LK,		255-LG1-LL-LM-LH-LJ-LN		;  * 
	.byte	255-LG2,		255-LG1-LM-LJ			;  + 
	.byte	255,			255-LN				;  , 
	.byte	255-LG2,		255-LG1				;  - 
	.byte	255-LP,			255				;  . 
	.byte	255-LK,			255-LN				;  / 
	.byte	255-LE-LD-LC-LB-LA-LK,	255-LF-LN			;  0 
	.byte	255-LC-LB-LK,		255				;  1 
	.byte	255-LG2-LE-LD-LB-LA,	255-LG1				;  2 
	.byte	255-LG2-LD-LC-LB-LA,	255				;  3 
	.byte	255-LG2-LC-LB,		255-LG1-LF			;  4 
	.byte	255-LD-LA,		255-LG1-LF-LL			;  5 
	.byte	255-LG2-LE-LD-LC-LA,	255-LG1-LF			;  6 
	.byte	255-LC-LB-LA,		255				;  7 
	.byte	255-LG2-LE-LD-LC-LB-LA,	255-LG1-LF			;  8 
	.byte	255-LG2-LD-LC-LB-LA,	255-LG1-LF			;  9 
	.byte	255,			255-LM-LJ			;  : 
	.byte	255,			255-LJ-LN			;  ; 
	.byte	255-LK,			255-LG1-LL			;  < 
	.byte	255-LG2-LD,		255-LG1				;  = 
	.byte	255-LG2,		255-LH-LN			;  > 
	.byte	255-LG2-LB-LA-LP,	255-LM				;  ? 
	.byte	255-LG2-LE-LD-LB-LA,	255-LF-LJ			;  @ 
	.byte	255-LG2-LE-LC-LB-LA,	255-LG1-LF			;  A 
	.byte	255-LG2-LD-LC-LB-LA,	255-LM-LJ			;  B 
	.byte	255-LE-LD-LA,		255-LF				;  C 
	.byte	255-LD-LC-LB-LA,	255-LM-LJ			;  D 
	.byte	255-LE-LD-LA,		255-LG1-LF			;  E 
	.byte	255-LE-LA,		255-LG1-LF			;  F 
	.byte	255-LG2-LE-LD-LC-LA,	255-LF				;  G 
	.byte	255-LG2-LE-LC-LB,	255-LG1-LF			;  H 
	.byte	255-LD-LA,		255-LM-LJ			;  I 
	.byte	255-LE-LD-LC-LB,	255				;  J 
	.byte	255-LE-LK,		255-LG1-LF-LL			;  K 
	.byte	255-LE-LD,		255-LF				;  L 
	.byte	255-LE-LC-LB-LK,	255-LF-LH			;  M 
	.byte	255-LE-LC-LB,		255-LF-LL-LH			;  N 
	.byte	255-LE-LD-LC-LB-LA,	255-LF				;  O 
	.byte	255-LG2-LE-LB-LA,	255-LG1-LF			;  P 
	.byte	255-LE-LD-LC-LB-LA,	255-LF-LL			;  Q 
	.byte	255-LG2-LE-LB-LA,	255-LG1-LF-LL			;  R 
	.byte	255-LG2-LD-LC-LA,	255-LG1-LF			;  S 
	.byte	255-LA,			255-LM-LJ			;  T 
	.byte	255-LE-LD-LC-LB,	255-LF				;  U 
	.byte	255-LE-LK,		255-LF-LN			;  V 
	.byte	255-LE-LC-LB,		255-LF-LL-LN			;  W 
	.byte	255-LK,			255-LL-LH-LN			;  X 
	.byte	255-LG2-LD-LC-LB,	255-LG1-LF			;  Y 
	.byte	255-LD-LA-LK,		255-LN				;  Z 
	.byte	255-LE-LD-LA,		255-LF				;  [ 
	.byte	255,			255-LL-LH			;  \ 
	.byte	255-LD-LC-LB-LA,	255				;  ] 
	.byte	255,			255-LL-LN			;  ^ 
	.byte	255-LD,			255				;  _ 
	.byte	255,			255-LH				;  ` 
	.byte	255-LE-LD,		255-LG1-LM			;  a 
	.byte	255-LE-LD,		255-LG1-LF-LL			;  b 
	.byte	255-LG2-LE-LD,		255-LG1				;  c 
	.byte	255-LG2-LD-LC-LB,	255-LN				;  d 
	.byte	255-LE-LD,		255-LG1-LN			;  e 
	.byte	255-LG2-LK,		255-LG1-LM			;  f 
	.byte	255-LG2-LD-LC-LB-LK,	255				;  g 
	.byte	255-LE,			255-LG1-LF-LM			;  h 
	.byte	255,			255-LM				;  i 
	.byte	255-LE,			255-LJ-LN			;  j 
	.byte	255-LK,			255-LL-LM-LJ			;  k 
	.byte	255-LE,			255-LF				;  l 
	.byte	255-LG2-LE-LC,		255-LG1-LM			;  m 
	.byte	255-LE,			255-LG1-LM			;  n 
	.byte	255-LG2-LE-LD-LC,	255-LG1				;  o 
	.byte	255-LE,			255-LG1-LF-LH			;  p 
	.byte	255-LG2-LC-LB-LK,	255				;  q 
	.byte	255-LE,			255-LG1				;  r 
	.byte	255-LG2-LD,		255-LL				;  s 
	.byte	255-LE-LD,		255-LG1-LF			;  t 
	.byte	255-LE-LD-LC,		255				;  u 
	.byte	255-LE,			255-LN				;  v 
	.byte	255-LE-LC,		255-LL-LN			;  w 
	.byte	255-LK,			255-LL-LH-LN			;  x 
	.byte	255-LG2-LD-LC-LB,	255-LJ				;  y 
	.byte	255-LD,			255-LG1-LN			;  z 
	.byte	255-LD-LA,		255-LG1-LH-LN			;  { 
	.byte	255,			255-LM-LJ			;  | 
	.byte	255-LG2-LD-LA-LK,	255-LL				;  } 
	.byte	255-LG2-LK,		255-LG1-LN			;  ~ 
	.byte	255,			255				;  (del) 
